# A

Part A with again includes.

```{.python .cb.run}
with open('a1.md') as fp:
    print(fp.read())
```

## Aa

Some text per the simplified include mechanism to also better verify the blank line handling.

\include{sub/as.md}

## Ab

End of part cascade.
